@@ -1,4 +1,4 @@
-from datetime import date, datetime
+from datetime import date, datetime, timedelta
 from typing import Optional, Any, List
 from uuid import UUID
 
@@ -16,6 +16,8 @@ from alpaca.trading.enums import (
     OrderSide,
     OrderClass,
     OrderStatus,
+    CorporateActionType,
+    CorporateActionDateType,
 )
 
 
@@ -426,3 +428,40 @@ class TrailingStopOrderRequest(OrderRequest):
             raise ValueError("Both trail_percent and trail_price cannot be set.")
 
         return values
+
+
+class GetCorporateAnnouncementsRequest(NonEmptyRequest):
+    """
+    Contains parameters for querying corporate action data.
+    Attributes:
+        ca_types (List[CorporateActionType]): A list of corporate action types.
+        since (date): The start (inclusive) of the date range when searching corporate action announcements.
+            The date range is limited to 90 days.
+        until (date): The end (inclusive) of the date range when searching corporate action announcements.
+            The date range is limited to 90 days.
+        symbol (Optional[str]): The symbol of the company initiating the announcement.
+        cusip (Optional[str]): The CUSIP of the company initiating the announcement.
+        date_type (Optional[CorporateActionDateType]): The date type for the announcement.
+    """
+
+    ca_types: List[CorporateActionType]
+    since: date
+    until: date
+    symbol: Optional[str]
+    cusip: Optional[str]
+    date_type: Optional[CorporateActionDateType]
+
+    @root_validator()
+    def root_validator(cls, values: dict) -> dict:
+
+        since = values.get("since")
+        until = values.get("until")
+
+        if (
+            since is not None
+            and until is not None
+            and (until - since) > timedelta(days=90)
+        ):
+            raise ValueError("The date range is limited to 90 days.")
+
+        return values
